==> org-lsst-ccs-ui-3.1.1-20190321.054136-4-sources.jar: org/lsst/ccs/gconsole/services/persist/DataPanelDescriptor.java <==
package org.lsst.ccs.gconsole.services.persist;

import java.io.Serializable;
import java.util.EnumSet;
import java.util.HashMap;
import javax.swing.JComponent;
import org.lsst.ccs.gconsole.base.Console;
import org.lsst.ccs.gconsole.base.panel.Panel;
import org.lsst.ccs.gconsole.base.panel.PanelManager;

/**
 * Descriptor of a graphical console data panel.
 * Contains information required to position the panel on the screen (open or closed,
 * docked or undocked, location, etc.) as well as any additional data that should be
 * associated with the panel through {@link PanelManager}.
 *
 * @author onoprien
 */
public class DataPanelDescriptor implements Serializable {

    private boolean open;
    private HashMap<String, Serializable> data;

    public boolean isOpen() {
        return open;
    }

    public void setOpen(boolean open) {
        this.open = open;
    }

    public HashMap<String, Serializable> getData() {
        return data;
    }

    public void setData(HashMap<String, Serializable> data) {
        this.data = data;
    }
    
    static public DataPanelDescriptor get(JComponent component) {
        DataPanelDescriptor desc = new DataPanelDescriptor();
        try {
            PanelManager panMan = Console.getConsole().getPanelManager();
            boolean docked = (Boolean) panMan.get(component, Panel.DOCKED);
            desc.setOpen(true);
            if (!docked) {
                HashMap<String,Serializable> m =panMan.get(component, EnumSet.of(Panel.DEVICE, Panel.DOCKED, Panel.ICONIZED, Panel.LAST_DESELECTED, Panel.LOCATION, Panel.MAXIMIZED, Panel.SELECTED, Panel.SIZE));
                desc.setData(m);
            }
        } catch (IllegalArgumentException | NullPointerException | ClassCastException x) {
            desc.setOpen(false);
        }
        return desc;
    }

}

==> org-lsst-ccs-ui-3.6.0-sources.jar: org/lsst/ccs/gconsole/services/persist/DataPanelDescriptor.java <==
package org.lsst.ccs.gconsole.services.persist;

import java.io.Serializable;
import java.util.EnumSet;
import java.util.HashMap;
import javax.swing.JComponent;
import org.lsst.ccs.gconsole.base.Console;
import org.lsst.ccs.gconsole.base.panel.Panel;
import org.lsst.ccs.gconsole.base.panel.PanelManager;

/**
 * Descriptor of a graphical console data panel.
 * Contains information required to position the panel on the screen (open or closed,
 * docked or undocked, location, etc.) as well as any additional data that should be
 * associated with the panel through {@link PanelManager}.
 *
 * @author onoprien
 */
public class DataPanelDescriptor implements Serializable, Cloneable {

    private boolean open;
    private HashMap<String, Serializable> data;
    
// -- Setters and getters : ----------------------------------------------------

    public boolean isOpen() {
        return open;
    }

    public void setOpen(boolean open) {
        this.open = open;
    }

    public HashMap<String, Serializable> getData() {
        return data;
    }

    public void setData(HashMap<String, Serializable> data) {
        this.data = data;
    }
    
    
// -- Cloning : ----------------------------------------------------------------
    
    @Override    
    public DataPanelDescriptor clone() {
        try {
            DataPanelDescriptor d = (DataPanelDescriptor) super.clone();
            if (data != null) {
               d.data = (HashMap<String, Serializable>) data.clone();
            }
            return d;
        } catch (CloneNotSupportedException x) {
            return null; // never
        }
    }

// -- Static utilities : -------------------------------------------------------
    
    public static DataPanelDescriptor get(JComponent component) {
        DataPanelDescriptor desc = new DataPanelDescriptor();
        try {
            PanelManager panMan = Console.getConsole().getPanelManager();
            boolean docked = (Boolean) panMan.get(component, Panel.DOCKED);
            desc.setOpen(true);
            if (!docked) {
                HashMap<String,Serializable> m =panMan.get(component, EnumSet.of(Panel.DEVICE, Panel.DOCKED, Panel.ICONIZED, Panel.LAST_DESELECTED, Panel.LOCATION, Panel.MAXIMIZED, Panel.SELECTED, Panel.SIZE));
                desc.setData(m);
            }
        } catch (IllegalArgumentException | NullPointerException | ClassCastException x) {
            desc.setOpen(false);
        }
        return desc;
    }

}
